@@ -20,7 +20,7 @@
 #' @keywords internal
 #' @noRd
 .conj_beta_mv <- function(s1 = NULL, priors = NULL,
-                          plot = FALSE, support = NULL, cred.int.level = NULL,
+                          support = NULL, cred.int.level = NULL,
                           calculatingSupport = FALSE) {
   #* `make default prior if none provided`
   if (is.null(priors)) {
@@ -69,16 +69,18 @@
   out$summary <- data.frame(HDE_1 = hde1, HDI_1_low = hdi1[1], HDI_1_high = hdi1[2])
   out$posterior$a <- a1_prime
   out$posterior$b <- b1_prime
+  out$prior <- priors
   #* `Make Posterior Draws`
   out$posteriorDraws <- rbeta(10000, a1_prime, b1_prime)
   out$pdf <- pdf1
   #* `keep data for plotting`
-  if (plot) {
-    out$plot_df <- data.frame(
-      "range" = support, "prob" = pdf1,
-      "sample" = rep("Sample 1", length(support))
-    )
-  }
+  out$plot_list <- list(
+    "range" = range(support),
+    "ddist_fun" = "stats::dbeta",
+    "priors" = list("shape1" = priors$a[1],  "shape2" = priors$b[1]),
+    "parameters" = list("shape1" = a1_prime,
+                        "shape2" = b1_prime)
+  )
 
   return(out)
 }
@@ -99,7 +101,7 @@
 #' @keywords internal
 #' @noRd
 .conj_beta_sv <- function(s1 = NULL, priors = NULL,
-                          plot = FALSE, support = NULL, cred.int.level = NULL,
+                          support = NULL, cred.int.level = NULL,
                           calculatingSupport = FALSE) {
   if (any(c(s1) > 1) || any(c(s1) < 0)) {
     stop("Beta Distribution is only defined on [0,1]")
@@ -141,16 +143,18 @@
   out$summary <- data.frame(HDE_1 = hde1, HDI_1_low = hdi1[1], HDI_1_high = hdi1[2])
   out$posterior$a <- a1_prime
   out$posterior$b <- b1_prime
+  out$prior <- priors
   #* `Make Posterior Draws`
   out$posteriorDraws <- rbeta(10000, a1_prime, b1_prime)
   out$pdf <- pdf1
   #* `keep data for plotting`
-  if (plot) {
-    out$plot_df <- data.frame(
-      "range" = support, "prob" = pdf1,
-      "sample" = rep("Sample 1", length(support))
-    )
-  }
+  out$plot_list <- list(
+    "range" = range(support),
+    "ddist_fun" = "stats::dbeta",
+    "priors" = list("shape1" = priors$a[1],  "shape2" = priors$b[1]),
+    "parameters" = list("shape1" = a1_prime,
+                        "shape2" = b1_prime)
+  )
   return(out)
 }
 
