@@ -30,7 +30,7 @@
 #' @noRd
 
 .conj_negbin_sv <- function(s1 = NULL, priors = NULL,
-                            plot = FALSE, support = NULL, cred.int.level = NULL,
+                            support = NULL, cred.int.level = NULL,
                             calculatingSupport = FALSE) {
   #* `Check samples`
   if (any(abs(s1 - round(s1)) > .Machine$double.eps^0.5) || any(s1 < 0)) {
@@ -70,15 +70,18 @@
   out$posterior$r <- priors$r[1]
   out$posterior$a <- a1_prime
   out$posterior$b <- b1_prime
+  out$prior <- priors
   #* `Make Posterior Draws`
   out$posteriorDraws <- rbeta(10000, a1_prime, b1_prime)
   out$pdf <- pdf1
   #* `keep data for plotting`
-  if (plot) {
-    out$plot_df <- data.frame(
-      "range" = support, "prob" = pdf1,
-      "sample" = rep("Sample 1", length(support))
-    )
-  }
+  out$plot_list <- list(
+    "range" = range(support),
+    "ddist_fun" = "stats::dbeta",
+    "priors" = list("shape1" = priors$a[1],  "shape2" = priors$b[1]),
+    "parameters" = list("shape1" = a1_prime,
+                        "shape2" = b1_prime),
+    "given" = list("size" = priors$r[1])
+  )
   return(out)
 }
