@@ -10,7 +10,8 @@
 #' specifying "model1 + model2", see examples and \code{\link{growthSS}}.
 #' Decay can be specified by including "decay" as part of the model such as "logistic decay" or
 #' "linear + linear decay". Count data can be specified with the "count: " prefix,
-#' similar to using "poisson: model" in \link{growthSS}.
+#' similar to using "poisson: model" in \link{growthSS}. Similarly intercepts can be added with the
+#' "int_" prefix, in which case an "I" parameter should be specified.
 #' While "gam" models are supported by \code{growthSS}
 #' they are not simulated by this function.
 #' @param n Number of individuals to simulate over time per each group in params
@@ -115,6 +116,14 @@
 #'   geom_line(aes(color = group)) +
 #'   labs(title = "Linear")
 #'
+#' simdf <- growthSim("int_linear",
+#'   n = 20, t = 25,
+#'   params = list("A" = c(1.1, 0.95), I = c(100, 120))
+#' )
+#' ggplot(simdf, aes(time, y, group = interaction(group, id))) +
+#'   geom_line(aes(color = group)) +
+#'   labs(title = "Linear with Intercept")
+#'
 #' simdf <- growthSim("logarithmic",
 #'   n = 20, t = 25,
 #'   params = list("A" = c(2, 1.7))
@@ -243,6 +252,11 @@ growthSim <- function(
   } else {
     COUNT <- FALSE
   }
+  int <- FALSE
+  if (grepl("^int", model)) {
+    int <- TRUE
+    model <- trimws(sub("^int_?", "", model))
+  }
   if (is.null(names(params))) {
     names(params) <- c(LETTERS[seq_along(params)])
   }
@@ -269,20 +283,21 @@ growthSim <- function(
     params[diffLengths] <- lapply(
       diffLengths,
       function(i) {
-        rep(params[[i]], length.out = max(unlist(lapply(params, length))))
+        i_reps <- rep(params[[i]], length.out = max(unlist(lapply(params, length))))
+        return(i_reps)
       }
     )
   }
   #* decide which internal funciton to use
   if (!grepl("\\+", model)) {
-    out <- .singleGrowthSim(model, n, t, params, noise, D)
+    out <- .singleGrowthSim(model, n, t, params, noise, D, int)
   } else {
-    out <- .multiGrowthSim(model, n, t, params, noise, D)
+    out <- .multiGrowthSim(model, n, t, params, noise, D, int)
   }
   if (COUNT) {
     out <- do.call(rbind, lapply(split(out, interaction(out$group, out$id)), function(sub) {
       sub$y <- round(cummax(sub$y))
-      sub
+      return(sub)
     }))
     rownames(out) <- NULL
   }
@@ -293,7 +308,7 @@ growthSim <- function(
 #' @keywords internal
 #' @noRd
 
-.multiGrowthSim <- function(model, n = 20, t = 25, params = list(), noise = NULL, D = 0) {
+.multiGrowthSim <- function(model, n = 20, t = 25, params = list(), noise = NULL, D = 0, int) {
   component_models <- trimws(strsplit(model, "\\+")[[1]])
 
   firstModel <- component_models[1]
@@ -308,26 +323,27 @@ growthSim <- function(
     stop("Simulating segmented data requires 'changePointX' parameters as described in growthSS.")
   }
 
-  df1 <- do.call(rbind, lapply(1:n, function(i) {
+  df1 <- do.call(rbind, lapply(seq_len(n), function(i) {
     firstChangepointsRand <- lapply(firstChangepoints, function(fc) {
-      round(rnorm(1, fc, firstNoise$change))
+      return(round(rnorm(1, fc, firstNoise$change)))
     })
 
     n_df <- do.call(rbind, lapply(seq_along(firstChangepointsRand), function(g) {
-      .singleGrowthSim(firstModel,
+      g_df <- .singleGrowthSim(firstModel,
         n = 1, t = firstChangepointsRand[[g]],
         params = stats::setNames(
           lapply(firstParams, function(l) l[[g]]),
           c(sub(paste0(firstModel, "1"), "", names(firstParams)))
         ),
-        noise = firstNoise, D
+        noise = firstNoise, D, int
       )
+      return(g_df)
     }))
     n_df$group <- rep(letters[seq_along(firstChangepointsRand)],
       times = unlist(firstChangepointsRand)
     )
     n_df$id <- paste0("id_", i)
-    n_df
+    return(n_df)
   }))
   dataList <- list(df1)
 
@@ -346,7 +362,7 @@ growthSim <- function(
         iterChangepointsRand <- rep(t, length(iterParams[[1]]))
       } else {
         iterChangepointsRand <- lapply(nextChangepoints, function(fc) {
-          round(rnorm(1, fc, iterNoise$change))
+          return(round(rnorm(1, fc, iterNoise$change)))
         })
       }
       n_df <- do.call(rbind, lapply(seq_along(iterChangepointsRand), function(g) {
@@ -363,13 +379,13 @@ growthSim <- function(
             lapply(iterParams, function(l) l[[g]]),
             c(sub(paste0(iterModelFindParams, u), "", names(iterParams)))
           ),
-          noise = iterNoise, D
+          noise = iterNoise, D, int = FALSE
         )
         inner_df$group <- letters[g]
-        inner_df
+        return(inner_df)
       }))
       n_df$id <- paste0("id_", i)
-      n_df
+      return(n_df)
     }))
 
     prev_data <- dataList[[(u - 1)]]
@@ -381,7 +397,7 @@ growthSim <- function(
       iter_data_sub$time <- iter_data_sub$time + max(prev_data_sub$time)
       iter_data_sub$y <- iter_data_sub$y - iter_data_sub$y[1]
       iter_data_sub$y <- y_end + iter_data_sub$y
-      iter_data_sub
+      return(iter_data_sub)
     }))
     dataList[[(u)]] <- new_data
   }
@@ -397,7 +413,7 @@ growthSim <- function(
 #' @keywords internal
 #' @noRd
 
-.singleGrowthSim <- function(model, n = 20, t = 25, params = list(), noise = NULL, D) {
+.singleGrowthSim <- function(model, n = 20, t = 25, params = list(), noise = NULL, D, int) {
   models <- c(
     "logistic", "gompertz", "double logistic", "double gompertz",
     "monomolecular", "exponential", "linear", "power law", "frechet", "weibull", "gumbel",
@@ -416,22 +432,27 @@ growthSim <- function(
 
   if (decay) {
     gsid <- function(D = 0, ...) {
-      D - gsi(...)
+      return(D - gsi(...))
     }
   } else {
     gsid <- function(D = 0, ...) {
-      0 + gsi(...)
+      return(0 + gsi(...))
     }
   }
 
   out <- do.call(rbind, lapply(seq_along(params[[1]]), function(i) {
     pars <- lapply(params, function(p) p[i])
-    as.data.frame(rbind(do.call(rbind, lapply(1:n, function(e) {
-      data.frame(
+    e_df <- as.data.frame(rbind(do.call(rbind, lapply(1:n, function(e) {
+      iter_data <- data.frame(
         "id" = paste0("id_", e), "group" = letters[i], "time" = 1:t,
         "y" = gsid(D = D, 1:t, pars, noise), stringsAsFactors = FALSE
       )
+      if (int) {
+        iter_data$y <- iter_data$y + rnorm(1, mean = pars[["I"]], sd = noise[["I"]])
+      }
+      return(iter_data)
     }))))
+    return(e_df)
   }))
 
   return(out)
