@@ -47,21 +47,23 @@ plotPrior <- function(priors, type = "density", n = 200, t = 25) {
       support <- seq(0, max, length.out = 10000)
       dens <- dlnorm(support, meanlog = log(prio), sdlog = 0.25)
       pdf <- dens / sum(dens)
-      data.frame(
+      pri_df_o <- data.frame(
         support = support,
         dens = pdf,
         param = nm,
         item = as.character(o)
       )
+      return(pri_df_o)
     }))
 
-    ggplot2::ggplot(pri_df, ggplot2::aes(
+    p <- ggplot2::ggplot(pri_df, ggplot2::aes(
       x = .data$support, y = .data$dens,
       fill = .data$item, group = .data$item
     )) +
       ggplot2::geom_polygon(alpha = 0.5) +
       ggplot2::theme_minimal() +
       ggplot2::labs(y = "Density", title = nm, fill = "Prior")
+    return(p)
   })
   names(densPlots) <- names(priors)
 
@@ -72,7 +74,7 @@ plotPrior <- function(priors, type = "density", n = 200, t = 25) {
       iter_params <- .prior_sampler(priors)
       x <- growthSim(model = type, n = 1, t = t, params = iter_params)
       x$id <- paste0("id_", i)
-      x
+      return(x)
     }))
 
     model_plot <- ggplot2::ggplot(
@@ -196,11 +198,13 @@ plotPrior <- function(priors, type = "density", n = 200, t = 25) {
 #' @noRd
 
 .prior_sampler <- function(priors) {
-  lapply(priors, function(pri) { # draw sample from prior
-    unlist(lapply(pri, function(mu) {
-      rlnorm(1, log(mu), 0.25)
+  pri_list <- lapply(priors, function(pri) { # draw sample from prior
+    pri_vec <- unlist(lapply(pri, function(mu) {
+      return(rlnorm(1, log(mu), 0.25))
     }))
+    return(pri_vec)
   })
+  return(pri_list)
 }
 
 #' @description
@@ -229,7 +233,7 @@ plotPrior <- function(priors, type = "density", n = 200, t = 25) {
     },
     error = function(err) {
       message(paste0(
-        "Error trying to sample from priors distributions.",
+        "Error trying to sample from prior distributions. ",
         "All priors must be proper (non-flat). Check prior specification in growthSS\n"
       ))
       message("The original Error message is:")
