@@ -24,94 +24,98 @@
 #' account. This defaults to 0, meaning that if a plant were watered directly before being imaged then
 #' that water would be counted towards WUE between the current image and the prior one.
 #' This argument is taken to be in seconds.
-#' @param waterCol Column containing watering amounts in \code{w}. This defaults to "watering_amount".
-#' @param method Which method to use, options are "rate" and "abs". The "rate" method considers WUE as
-#' the change in a phenotype divided by the amount of water added. The "abs" method considers WUE as
-#' the amount of water used by a plant given its absolute size. The former is for questions more
-#' related to efficiency in using water to grow while the latter is more suited to questions about
-#' how efficient a plant is at maintaining size given some amount of water.
+#' @param pre_watering Column containing weight before watering in \code{w},
+#' defaults to "weight_before".
+#' @param post_watering Column containing weight after watering in \code{w},
+#' defaults to "weight_after".
+#' @param method Which method to use, options are "rate", "abs", and "ndt". The "rate" method considers
+#' WUE as the change in a phenotype divided by the amount of water added. The "abs" method considers WUE
+#' as the amount of water used by a plant given its absolute size.
+#' The "ndt" method calculates normalized daily transpiration,
+#' which is the reciprocal of the "abs" method. The "rate" method is for questions more
+#' related to efficiency in using water to grow while "abs"/"ndt" are more suited to questions about
+#' how efficient a plant is at maintaining size given some amount of water or how much water it uses
+#' at a given size.
 #' @keywords WUE
 #' @import data.table
-#' @return A data frame containing the bellwether watering data joined
-#'     to phenotype data with new columns for change in the phenotype,
-#'     change in the pre-watering weight, and pseudo-water use efficiency (pWUE).
+#' @return A data frame containing the watering data and
+#'     to phenotype data with new columns for change in the phenotype (\code{pheno_diff}),
+#'     amount of water used (\code{total_water}) over the interval between phenotype measurements
+#'     (water added post to pre phenotype measurement), \code{start} and \code{end} times for the
+#'     interval as well as their difference (\code{timeLengthSeconds}), and pseudo water use efficiency
+#'     (\code{pWUE}).
 #' @examples
-#' sim_water <- data.frame(
-#'   "barcode" = "exampleBarcode1",
-#'   "timestamp" = as.POSIXct(c(
-#'     "2023-04-13 23:28:17 UTC",
-#'     "2023-04-22 05:30:42 UTC",
-#'     "2023-05-04 18:55:38 UTC"
-#'   )),
-#'   "DAS" = c(0.000000, 8.251675, 20.810660),
-#'   "water_amount" = c(98, 12, -1)
-#' )
-#' sim_df <- data.frame(
-#'   "barcode" = "exampleBarcode1",
-#'   "timestamp" = as.POSIXct(c(
-#'     "2023-04-13 23:28:17 UTC",
-#'     "2023-04-22 05:30:42 UTC",
-#'     "2023-05-04 18:55:38 UTC"
-#'   )),
-#'   "DAS" = c(0.000000, 8, 20),
-#'   "area_pixels" = c(20, 1000, 1500)
-#' )
-#' pwue(
-#'   df = sim_df, w = sim_water, pheno = "area_pixels",
-#'   time = "timestamp", id = "barcode", offset = 0,
-#'   waterCol = "water_amount", method = "rate"
-#' )
 #'
-#' pwue(
-#'   df = sim_df, w = sim_water, pheno = "area_pixels",
-#'   time = c("timestamp", "timestamp"), id = "barcode", offset = 0,
-#'   waterCol = "water_amount", method = "abs"
+#' set.seed(123)
+#' weight_before <- sort(round(rnorm(20, 100, 10), 0))
+#' weight_after <- sort(round(rnorm(20, 120, 10), 0))
+#' df <- data.frame(
+#'   time = seq_along(weight_before),
+#'   area_pixels = round(130 / (1 + exp( (12 - seq_along(weight_before))/3) ), 0),
+#'   weight_before,
+#'   weight_after,
+#'   barcode = 1,
+#'   other = "x"
 #' )
+#' ex <- pwue(df, time = "time", method = "rate", id = c("barcode", "other"))
+#' w <- df[, c("time", "weight_before", "weight_after", "barcode")]
+#' ex2 <- pwue(df, w, time = c("time", "time"), method = "abs")
+#' ex3 <- pwue(df, w, time = c("time", "time"), method = "ndt")
 #'
 #' @export
 
-pwue <- function(df, w, pheno = "area_pixels", time = "timestamp", id = "barcode",
-                 offset = 0, waterCol = "water_amount", method = "rate") {
+pwue <- function(df, w = NULL, pheno = "area_pixels", time = "timestamp", id = "barcode",
+                 offset = 0, pre_watering = "weight_before", post_watering = "weight_after",
+                 method = "rate") {
   if (length(time) == 2) {
     time1 <- time[1]
     time2 <- time[2]
   } else {
     time1 <- time2 <- time
   }
-  if (!time1 %in% colnames(df) || !time2 %in% colnames(w)) {
-    stop(paste0(paste0(time, collapse = ", "), " must be in colnames of df and w"))
+  if (is.null(w)) {
+    w <- df[, c(time2, id, pre_watering, post_watering)]
   }
-
+  if (length(id) > 1) {
+    df$temporary_pwue_id_column <- interaction(df[, c(id)])
+    w$temporary_pwue_id_column <- interaction(w[, c(id)])
+    id <- "temporary_pwue_id_column"
+  }
+  #* order data
   w <- data.table::setorderv(data.table::as.data.table(w), cols = c(id, time2))
-  w <- w[w[[waterCol]] > 0, ]
   df <- data.table::setorderv(data.table::as.data.table(df), cols = c(id, time1))
-  ids <- intersect(unique(w[, get(id)]), unique(df[, get(id)]))
-  matched_method <- match.arg(method, choices = c("rate", "abs"))
-
-  if (matched_method == "abs") {
-    out <- .absWUE(ids, w, df, offset, time1, time2, pheno, id, waterCol)
-  } else if (matched_method == "rate") {
-    out <- .rateWUE(ids, w, df, offset, time1, time2, pheno, id, waterCol)
-  }
-  return(as.data.frame(out))
+  data.table::setkeyv(w, id)
+  data.table::setkeyv(df, id)
+  ids <- intersect(unique(w[[id]]), unique(df[[id]]))
+  matched_method <- match.arg(method, choices = c("rate", "abs", "ndt"))
+  #* apply method
+  matched_fun <- get(paste0(".", matched_method, "WUE"))
+  out <- matched_fun(ids, w, df, offset, time1, time2, pheno, id, pre_watering, post_watering)
+  out <- as.data.frame(out)
+  out <- out[, which(colnames(out) != "temporary_pwue_id_column")]
+  # return data
+  return(out)
 }
 
 #' Function to calculate rate based WUE
 #' @keywords internal
 #' @noRd
 
-.rateWUE <- function(ids, w, df, offset, time1, time2, pheno, id, waterCol) {
+.rateWUE <- function(ids, w, df, offset, time1, time2, pheno, id, pre_watering, post_watering) {
   out <- do.call(rbind, lapply(ids, function(iter_id) { # per id...
-    w_i <- w[w[, get(id)] == iter_id, ]
-    df_i <- df[df[, get(id)] == iter_id, ]
+    w_i <- w[list(iter_id)]
+    df_i <- df[list(iter_id)]
     #* reorder watering and pheno data
     w_i <- data.table::setorderv(w_i, cols = c(time2))
     df_i <- data.table::setorderv(df_i, cols = c(time1))
+    #* get post_watering_weight_[t-1] and pre_watering_weight_[t] difference as column
+    w_i$deltaw <- data.table::shift(w_i[[post_watering]],
+                                    n = 1, type = "lag") - w_i[[pre_watering]]
     #* get unique imaging times
     imaging_times <- unique(df_i[[time1]])
     #* set water from before first image to zero so that
     #* offset does not grab water from before imaging starts.
-    w_i[[waterCol]] <- as.numeric(ifelse(w_i[[time2]] < imaging_times[1], 0, w_i[[waterCol]]))
+    w_i[["deltaw"]] <- as.numeric(ifelse(w_i[[time2]] < imaging_times[1], 0, w_i[["deltaw"]]))
     #* per imaging time
     wue_i <- do.call(rbind, lapply(seq_along(imaging_times), function(t_i) {
       start <- if (t_i == 1) {
@@ -127,8 +131,8 @@ pwue <- function(df, w, pheno = "area_pixels", time = "timestamp", id = "barcode
       end <- imaging_times[t_i] - offset
       endNonOffset <- imaging_times[t_i]
       if (!is.na(start)) {
-        w_i_t <- w_i[w_i[[time2]] > start & w_i[[time2]] < end, ]
-        total_water_i <- max(c(sum(w_i_t[[waterCol]]), 1))
+        w_i_t <- w_i[w_i[[time2]] > start & w_i[[time2]] <= end, ]
+        total_water_i <- sum(w_i_t[["deltaw"]])
         pheno_diff <- max(c(
           as.numeric(df_i[df_i[[time1]] == endNonOffset, get(pheno)] - df_i[
             df_i[[time1]] == startNonOffset, get(pheno)
@@ -138,7 +142,7 @@ pwue <- function(df, w, pheno = "area_pixels", time = "timestamp", id = "barcode
         total_water_i <- NA
         pheno_diff <- NA
       }
-
+      # make data to return
       row <- data.frame(
         total_water = total_water_i,
         pheno_diff = pheno_diff,
@@ -161,18 +165,21 @@ pwue <- function(df, w, pheno = "area_pixels", time = "timestamp", id = "barcode
 #' @noRd
 
 
-.absWUE <- function(ids, w, df, offset, time1, time2, pheno, id, waterCol) {
+.absWUE <- function(ids, w, df, offset, time1, time2, pheno, id, pre_watering, post_watering) {
   out <- do.call(rbind, lapply(ids, function(iter_id) { # per id...
-    w_i <- w[w[[id]] == iter_id, ]
-    df_i <- df[df[[id]] == iter_id, ]
+    w_i <- w[list(iter_id)]
+    df_i <- df[list(iter_id)]
     #* reorder watering and pheno data
     w_i <- data.table::setorderv(w_i, cols = c(time2))
     df_i <- data.table::setorderv(df_i, cols = c(time1))
+    #* get post_watering_weight_[t-1] and pre_watering_weight_[t] difference as column
+    w_i$deltaw <- data.table::shift(w_i[[post_watering]],
+                                    n = 1, type = "lag") - w_i[[pre_watering]]
     #* get unique imaging times
     imaging_times <- unique(df_i[[time1]])
     #* set water from before first image to zero so that offset
     #* does not grab water from before imaging starts.
-    w_i[[waterCol]] <- ifelse(w_i[[time2]] < imaging_times[1], 0, w_i[[time2]])
+    w_i[["deltaw"]] <- ifelse(w_i[[time2]] < imaging_times[1], 0, w_i[["deltaw"]])
     #* per imaging time
     wue_i <- do.call(rbind, lapply(seq_along(imaging_times), function(t_i) {
       start <- if (t_i == 1) {
@@ -187,16 +194,16 @@ pwue <- function(df, w, pheno = "area_pixels", time = "timestamp", id = "barcode
       }
       end <- imaging_times[t_i] - offset
       endNonOffset <- imaging_times[t_i]
-
+      # here we use the phenotype at this time, not the change in phenotype
       if (!is.na(start)) {
-        w_i_t <- w_i[w_i[[time2]] > start & w_i[[time2]] < end, ]
-        total_water_i <- max(c(sum(w_i_t[[waterCol]]), 1))
+        w_i_t <- w_i[w_i[[time2]] > start & w_i[[time2]] <= end, ]
+        total_water_i <- sum(w_i_t[["deltaw"]])
         pheno_iter <- max(df_i[df_i[[time1]] == endNonOffset, get(pheno)], na.rm = TRUE)
       } else {
         total_water_i <- NA
         pheno_iter <- NA
       }
-
+      # make data to return
       row <- data.frame(
         total_water = total_water_i,
         pheno_iter = pheno_iter,
@@ -213,3 +220,14 @@ pwue <- function(df, w, pheno = "area_pixels", time = "timestamp", id = "barcode
   }))
   return(out)
 }
+
+#' Function to calculate normalized daily transpiration
+#' @keywords internal
+#' @noRd
+
+
+.ndtWUE <- function(ids, w, df, offset, time1, time2, pheno, id, pre_watering, post_watering) {
+  out <- .absWUE(ids, w, df, offset, time1, time2, pheno, id, pre_watering, post_watering)
+  out$normalized_daily_transpiration <- 1 / out$pWUE
+  return(out)
+}
