@@ -9,15 +9,15 @@ library(patchwork) # for easy ggplot manipulation/combination
 library(brms)
 
 ## ----eval = FALSE-------------------------------------------------------------
-#  if (!"cmdstanr" %in% installed.packages()) {
-#    install.packages("cmdstanr", repos = c("https://mc-stan.org/r-packages/", getOption("repos")))
-#  }
-#  if (!"brms" %in% installed.packages()) {
-#    install.packages("brms")
-#  }
-#  library(brms)
-#  library(cmdstanr)
-#  cmdstanr::install_cmdstan()
+# if (!"cmdstanr" %in% installed.packages()) {
+#   install.packages("cmdstanr", repos = c("https://mc-stan.org/r-packages/", getOption("repos")))
+# }
+# if (!"brms" %in% installed.packages()) {
+#   install.packages("brms")
+# }
+# library(brms)
+# library(cmdstanr)
+# cmdstanr::install_cmdstan()
 
 ## -----------------------------------------------------------------------------
 simdf <- growthSim("logistic", n = 20, t = 25, params = list(
@@ -91,7 +91,7 @@ ggplot(sigma_df, aes(x = time, y = y, group = group)) +
 
 ## ----message = FALSE----------------------------------------------------------
 draw_gomp_sigma <- function(x) {
-  23 * exp(-21 * exp(-0.22 * x))
+  return(23 * exp(-21 * exp(-0.22 * x)))
 }
 ggplot(sigma_df, aes(x = time, y = y)) +
   geom_line(aes(group = group), color = "gray60") +
@@ -123,9 +123,9 @@ ss <- growthSS(
 ss
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  fit_h <- fitGrowth(ss, iter = 1000, cores = 4, chains = 4, silent = 0)
-#  
-#  brmPlot(fit_h, form = ss$pcvrForm, df = ss$df)
+# fit_h <- fitGrowth(ss, iter = 1000, cores = 4, chains = 4, silent = 0)
+# 
+# brmPlot(fit_h, form = ss$pcvrForm, df = ss$df)
 
 ## -----------------------------------------------------------------------------
 ss <- growthSS(
@@ -136,15 +136,15 @@ ss <- growthSS(
 ss
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  fit_l <- fitGrowth(ss,
-#    iter = 1000, cores = 4, chains = 4, silent = 0,
-#    control = list(adapt_delta = 0.999, max_treedepth = 20)
-#  )
-#  
-#  p1 <- brmPlot(fit_l, form = ss$pcvrForm, df = ss$df)
-#  p2 <- p1 + coord_cartesian(ylim = c(0, 300))
-#  p <- p1 / p2
-#  p
+# fit_l <- fitGrowth(ss,
+#   iter = 1000, cores = 4, chains = 4, silent = 0,
+#   control = list(adapt_delta = 0.999, max_treedepth = 20)
+# )
+# 
+# p1 <- brmPlot(fit_l, form = ss$pcvrForm, df = ss$df)
+# p2 <- p1 + coord_cartesian(ylim = c(0, 300))
+# p <- p1 / p2
+# p
 
 ## -----------------------------------------------------------------------------
 ss <- growthSS(
@@ -155,12 +155,12 @@ ss <- growthSS(
 ss
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  fit_s <- fitGrowth(ss,
-#    iter = 2000, cores = 4, chains = 4, silent = 0,
-#    control = list(adapt_delta = 0.999, max_treedepth = 20)
-#  )
-#  
-#  brmPlot(fit_s, form = ss$pcvrForm, df = ss$df)
+# fit_s <- fitGrowth(ss,
+#   iter = 2000, cores = 4, chains = 4, silent = 0,
+#   control = list(adapt_delta = 0.999, max_treedepth = 20)
+# )
+# 
+# brmPlot(fit_s, form = ss$pcvrForm, df = ss$df)
 
 ## -----------------------------------------------------------------------------
 ss <- growthSS(
@@ -175,25 +175,25 @@ ss <- growthSS(
 ss
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  fit_g <- fitGrowth(ss,
-#    iter = 2000, cores = 4, chains = 4, silent = 0,
-#    control = list(adapt_delta = 0.999, max_treedepth = 20)
-#  )
-#  
-#  brmPlot(fit_g, form = ss$pcvrForm, df = ss$df)
+# fit_g <- fitGrowth(ss,
+#   iter = 2000, cores = 4, chains = 4, silent = 0,
+#   control = list(adapt_delta = 0.999, max_treedepth = 20)
+# )
+# 
+# brmPlot(fit_g, form = ss$pcvrForm, df = ss$df)
 
 ## ----message = FALSE----------------------------------------------------------
 draw_gomp_sigma <- function(x) {
-  23 * exp(-21 * exp(-0.22 * x))
+  return(23 * exp(-21 * exp(-0.22 * x)))
 }
 draw_logistic_sigma <- function(x) {
-  20 / (1 + exp((15 - x) / 2))
+  return(20 / (1 + exp((15 - x) / 2)))
 }
 draw_logistic_exp <- function(x) {
-  2.5 * exp(0.08 * x)
+  return(2.5 * exp(0.08 * x))
 }
 draw_logistic_quad <- function(x) {
-  (0.3 * x) + (0.02 * x^2)
+  return((0.3 * x) + (0.02 * x^2))
 }
 
 ggplot(sigma_df, aes(x = time, y = y)) +
@@ -218,61 +218,61 @@ ggplot(sigma_df, aes(x = time, y = y)) +
   labs(y = "SD of y", title = "Gompertz Sigma", color = "")
 
 ## ----eval = FALSE-------------------------------------------------------------
-#  loo_spline <- add_criterion(fit_s, "loo")
-#  loo_homo <- add_criterion(fit_h, "loo")
-#  loo_linear <- add_criterion(fit_l, "loo")
-#  loo_gomp <- add_criterion(fit_g, "loo")
-#  
-#  h <- loo_homo$criteria$loo$estimates[3, 1]
-#  s <- loo_spline$criteria$loo$estimates[3, 1]
-#  l <- loo_linear$criteria$loo$estimates[3, 1]
-#  g <- loo_gomp$criteria$loo$estimates[3, 1]
-#  
-#  loodf <- data.frame(loo = c(h, s, l, g), model = c("Homosked", "Spline", "Linear", "Gompertz"))
-#  loodf$model <- factor(loodf$model, levels = unique(loodf$model[order(loodf$loo)]), ordered = TRUE)
-#  
-#  ggplot(
-#    loodf,
-#    aes(x = model, y = loo, fill = model)
-#  ) +
-#    geom_col() +
-#    scale_fill_viridis_d() +
-#    labs(y = "LOO Information Criteria", x = "Sub Model of Sigma") +
-#    theme_minimal() +
-#    theme(legend.position = "none")
+# loo_spline <- add_criterion(fit_s, "loo")
+# loo_homo <- add_criterion(fit_h, "loo")
+# loo_linear <- add_criterion(fit_l, "loo")
+# loo_gomp <- add_criterion(fit_g, "loo")
+# 
+# h <- loo_homo$criteria$loo$estimates[3, 1]
+# s <- loo_spline$criteria$loo$estimates[3, 1]
+# l <- loo_linear$criteria$loo$estimates[3, 1]
+# g <- loo_gomp$criteria$loo$estimates[3, 1]
+# 
+# loodf <- data.frame(loo = c(h, s, l, g), model = c("Homosked", "Spline", "Linear", "Gompertz"))
+# loodf$model <- factor(loodf$model, levels = unique(loodf$model[order(loodf$loo)]), ordered = TRUE)
+# 
+# ggplot(
+#   loodf,
+#   aes(x = model, y = loo, fill = model)
+# ) +
+#   geom_col() +
+#   scale_fill_viridis_d() +
+#   labs(y = "LOO Information Criteria", x = "Sub Model of Sigma") +
+#   theme_minimal() +
+#   theme(legend.position = "none")
 
 ## ----eval = FALSE-------------------------------------------------------------
-#  set.seed(345)
-#  ln <- growthSim("linear", n = 5, t = 10, params = list("A" = c(2, 3, 10)))
-#  
-#  strongPrior <- prior(student_t(3, 0, 5), dpar = "sigma", class = "b") +
-#    prior(gamma(2, 0.1), class = "nu", lb = 0.001) +
-#    prior(normal(10, .05), nlpar = "A", lb = 0)
-#  
-#  ss <- growthSS(
-#    model = "linear", form = y ~ time | id / group, sigma = "homo",
-#    df = ln, priors = strongPrior
-#  )
-#  
-#  fit <- fitGrowth(ss, iter = 1000, cores = 2, chains = 2, silent = 0)
-#  
-#  brmPlot(fit, form = ss$pcvrForm, df = ss$df) +
-#    coord_cartesian(ylim = c(0, 100))
+# set.seed(345)
+# ln <- growthSim("linear", n = 5, t = 10, params = list("A" = c(2, 3, 10)))
+# 
+# strongPrior <- prior(student_t(3, 0, 5), dpar = "sigma", class = "b") +
+#   prior(gamma(2, 0.1), class = "nu", lb = 0.001) +
+#   prior(normal(10, .05), nlpar = "A", lb = 0)
+# 
+# ss <- growthSS(
+#   model = "linear", form = y ~ time | id / group, sigma = "homo",
+#   df = ln, priors = strongPrior
+# )
+# 
+# fit <- fitGrowth(ss, iter = 1000, cores = 2, chains = 2, silent = 0)
+# 
+# brmPlot(fit, form = ss$pcvrForm, df = ss$df) +
+#   coord_cartesian(ylim = c(0, 100))
 
 ## ----eval = FALSE-------------------------------------------------------------
-#  weakPrior <- prior(student_t(3, 0, 5), dpar = "sigma", class = "b") +
-#    prior(gamma(2, 0.1), class = "nu", lb = 0.001) +
-#    prior(lognormal(log(10), 0.25), nlpar = "A", lb = 0)
-#  
-#  ss <- growthSS(
-#    model = "linear", form = y ~ time | id / group, sigma = "homo",
-#    df = ln, priors = weakPrior
-#  )
-#  
-#  fit <- fitGrowth(ss, iter = 1000, cores = 2, chains = 2, silent = 0)
-#  
-#  brmPlot(fit, form = ss$pcvrForm, df = ss$df) +
-#    coord_cartesian(ylim = c(0, 100))
+# weakPrior <- prior(student_t(3, 0, 5), dpar = "sigma", class = "b") +
+#   prior(gamma(2, 0.1), class = "nu", lb = 0.001) +
+#   prior(lognormal(log(10), 0.25), nlpar = "A", lb = 0)
+# 
+# ss <- growthSS(
+#   model = "linear", form = y ~ time | id / group, sigma = "homo",
+#   df = ln, priors = weakPrior
+# )
+# 
+# fit <- fitGrowth(ss, iter = 1000, cores = 2, chains = 2, silent = 0)
+# 
+# brmPlot(fit, form = ss$pcvrForm, df = ss$df) +
+#   coord_cartesian(ylim = c(0, 100))
 
 ## -----------------------------------------------------------------------------
 priors <- list("A" = 130, "B" = 10, "C" = 0.2)
@@ -331,11 +331,11 @@ mgcv_ss <- growthSS(
 )
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  brms_ss <- growthSS(
-#    model = "logistic", form = y ~ time | id / group,
-#    sigma = "spline", df = simdf,
-#    start = list("A" = 130, "B" = 10, "C" = 1)
-#  )
+# brms_ss <- growthSS(
+#   model = "logistic", form = y ~ time | id / group,
+#   sigma = "spline", df = simdf,
+#   start = list("A" = 130, "B" = 10, "C" = 1)
+# )
 
 ## -----------------------------------------------------------------------------
 ggplot(simdf, aes(time, y, group = interaction(group, id))) +
@@ -348,10 +348,10 @@ nlme_fit <- fitGrowth(nlme_ss)
 mgcv_fit <- fitGrowth(mgcv_ss)
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  brms_fit <- fitGrowth(brms_ss,
-#    iter = 500, cores = 1, chains = 1,
-#    control = list(adapt_delta = 0.999, max_treedepth = 20)
-#  )
+# brms_fit <- fitGrowth(brms_ss,
+#   iter = 500, cores = 1, chains = 1,
+#   control = list(adapt_delta = 0.999, max_treedepth = 20)
+# )
 
 ## ----warning=FALSE, message=FALSE---------------------------------------------
 growthPlot(nls_fit, form = nls_ss$pcvrForm, df = nls_ss$df)
@@ -360,7 +360,7 @@ growthPlot(nlme_fit, form = nlme_ss$pcvrForm, df = nlme_ss$df)
 growthPlot(mgcv_fit, form = mgcv_ss$pcvrForm, df = mgcv_ss$df)
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  growthPlot(brms_fit, form = brms_ss$pcvrForm, df = brms_ss$df)
+# growthPlot(brms_fit, form = brms_ss$pcvrForm, df = brms_ss$df)
 
 ## -----------------------------------------------------------------------------
 testGrowth(nls_ss, nls_fit, test = "A")$anova
@@ -390,7 +390,7 @@ testGrowth(fit = nlme_fit, test = list(
 ))
 
 ## ----echo=TRUE, eval=FALSE----------------------------------------------------
-#  (hyp <- brms::hypothesis(brms_fit, "(A_groupa) > 1.1 * (A_groupb)"))
+# (hyp <- brms::hypothesis(brms_fit, "(A_groupa) > 1.1 * (A_groupb)"))
 
 ## ----echo=FALSE, eval=TRUE----------------------------------------------------
 structure(list(
@@ -400,201 +400,205 @@ structure(list(
 ), row.names = c(NA, -1L), class = "data.frame")
 
 ## ----echo=TRUE, eval=FALSE----------------------------------------------------
-#  simdf <- growthSim(
-#    model = "linear + linear",
-#    n = 20, t = 25,
-#    params = list("linear1A" = c(15, 12), "changePoint1" = c(8, 6), "linear2A" = c(3, 5))
-#  )
-#  
-#  ss <- growthSS(
-#    model = "linear + linear", form = y ~ time | id / group, sigma = "spline",
-#    start = list("linear1A" = 10, "changePoint1" = 5, "linear2A" = 2),
-#    df = simdf, type = "brms"
-#  )
-#  
-#  fit <- fitGrowth(ss, backend = "cmdstanr", iter = 500, chains = 1, cores = 1)
+# simdf <- growthSim(
+#   model = "linear + linear",
+#   n = 20, t = 25,
+#   params = list("linear1A" = c(15, 12), "changePoint1" = c(8, 6), "linear2A" = c(3, 5))
+# )
+# 
+# ss <- growthSS(
+#   model = "linear + linear", form = y ~ time | id / group, sigma = "spline",
+#   start = list("linear1A" = 10, "changePoint1" = 5, "linear2A" = 2),
+#   df = simdf, type = "brms"
+# )
+# 
+# fit <- fitGrowth(ss, backend = "cmdstanr", iter = 500, chains = 1, cores = 1)
 
 ## ----echo=TRUE, eval=FALSE----------------------------------------------------
-#  simdf <- growthSim("linear + logistic",
-#    n = 20, t = 25,
-#    params = list(
-#      "linear1A" = c(15, 12), "changePoint1" = c(8, 6),
-#      "logistic2A" = c(100, 150), "logistic2B" = c(10, 8),
-#      "logistic2C" = c(3, 2.5)
-#    )
-#  )
-#  
-#  ss <- growthSS(
-#    model = "linear + logistic", form = y ~ time | id / group, sigma = "spline",
-#    list(
-#      "linear1A" = 10, "changePoint1" = 5,
-#      "logistic2A" = 100, "logistic2B" = 10, "logistic2C" = 3
-#    ),
-#    df = simdf, type = "brms"
-#  )
-#  
-#  fit <- fitGrowth(ss, backend = "cmdstanr", iter = 500, chains = 1, cores = 1)
+# simdf <- growthSim("linear + logistic",
+#   n = 20, t = 25,
+#   params = list(
+#     "linear1A" = c(15, 12), "changePoint1" = c(8, 6),
+#     "logistic2A" = c(100, 150), "logistic2B" = c(10, 8),
+#     "logistic2C" = c(3, 2.5)
+#   )
+# )
+# 
+# ss <- growthSS(
+#   model = "linear + logistic", form = y ~ time | id / group, sigma = "spline",
+#   list(
+#     "linear1A" = 10, "changePoint1" = 5,
+#     "logistic2A" = 100, "logistic2B" = 10, "logistic2C" = 3
+#   ),
+#   df = simdf, type = "brms"
+# )
+# 
+# fit <- fitGrowth(ss, backend = "cmdstanr", iter = 500, chains = 1, cores = 1)
 
 ## ----eval=FALSE, echo=TRUE----------------------------------------------------
-#  ss <- growthSS(
-#    model = "linear + gam", form = y ~ time | id / group, sigma = "int",
-#    list("linear1A" = 10, "changePoint1" = 5),
-#    df = simdf, type = "brms"
-#  )
-#  
-#  fit <- fitGrowth(ss, backend = "cmdstanr", iter = 500, chains = 1, cores = 1)
+# ss <- growthSS(
+#   model = "linear + gam", form = y ~ time | id / group, sigma = "int",
+#   list("linear1A" = 10, "changePoint1" = 5),
+#   df = simdf, type = "brms"
+# )
+# 
+# fit <- fitGrowth(ss, backend = "cmdstanr", iter = 500, chains = 1, cores = 1)
 
 ## ----echo=TRUE, eval=FALSE----------------------------------------------------
-#  simdf <- growthSim("linear + linear + linear",
-#    n = 25, t = 50,
-#    params = list(
-#      "linear1A" = c(10, 12), "changePoint1" = c(8, 6),
-#      "linear2A" = c(1, 2), "changePoint2" = c(25, 30), "linear3A" = c(20, 24)
-#    )
-#  )
-#  
-#  ss <- growthSS(
-#    model = "linear + linear + linear", form = y ~ time | id / group, sigma = "spline",
-#    list(
-#      "linear1A" = 10, "changePoint1" = 5,
-#      "linear2A" = 2, "changePoint2" = 15,
-#      "linear3A" = 5
-#    ), df = simdf, type = "brms"
-#  )
-#  
-#  fit <- fitGrowth(ss, backend = "cmdstanr", iter = 500, chains = 1, cores = 1)
+# simdf <- growthSim("linear + linear + linear",
+#   n = 25, t = 50,
+#   params = list(
+#     "linear1A" = c(10, 12), "changePoint1" = c(8, 6),
+#     "linear2A" = c(1, 2), "changePoint2" = c(25, 30), "linear3A" = c(20, 24)
+#   )
+# )
+# 
+# ss <- growthSS(
+#   model = "linear + linear + linear", form = y ~ time | id / group, sigma = "spline",
+#   list(
+#     "linear1A" = 10, "changePoint1" = 5,
+#     "linear2A" = 2, "changePoint2" = 15,
+#     "linear3A" = 5
+#   ), df = simdf, type = "brms"
+# )
+# 
+# fit <- fitGrowth(ss, backend = "cmdstanr", iter = 500, chains = 1, cores = 1)
 
 ## ----echo=FALSE, eval=FALSE---------------------------------------------------
-#  set.seed(123)
-#  noise <- do.call(rbind, lapply(1:30, function(i) {
-#    chngpt <- rnorm(2, 18, 2)
-#    rbind(
-#      data.frame(
-#        id = paste0("id_", i), time = 1:chngpt[1], group = "a",
-#        y = c(runif(chngpt[1] - 1, 0, 20), rnorm(1, 5, 1))
-#      ),
-#      data.frame(
-#        id = paste0("id_", i), time = 1:chngpt[2], group = "b",
-#        y = c(runif(chngpt[2] - 1, 0, 20), rnorm(1, 5, 1))
-#      )
-#    )
-#  }))
-#  noise2 <- do.call(rbind, lapply(1:30, function(i) {
-#    start1 <- max(noise[noise$id == paste0("id_", i) & noise$group == "a", "time"])
-#    start2 <- max(noise[noise$id == paste0("id_", i) & noise$group == "b", "time"])
-#    rbind(
-#      data.frame(
-#        id = paste0("id_", i), time = start1:40, group = "a",
-#        y = c(runif(length(start1:40), 15, 50))
-#      ),
-#      data.frame(
-#        id = paste0("id_", i), time = start2:40, group = "b",
-#        y = c(runif(length(start2:40), 15, 50))
-#      )
-#    )
-#  }))
-#  simdf <- rbind(noise, noise2)
+# set.seed(123)
+# noise <- do.call(rbind, lapply(1:30, function(i) {
+#   chngpt <- rnorm(2, 18, 2)
+#   noise_i <- rbind(
+#     data.frame(
+#       id = paste0("id_", i), time = 1:chngpt[1], group = "a",
+#       y = c(runif(chngpt[1] - 1, 0, 20), rnorm(1, 5, 1))
+#     ),
+#     data.frame(
+#       id = paste0("id_", i), time = 1:chngpt[2], group = "b",
+#       y = c(runif(chngpt[2] - 1, 0, 20), rnorm(1, 5, 1))
+#     )
+#   )
+#   return(noise_i)
+# }))
+# noise2 <- do.call(rbind, lapply(1:30, function(i) {
+#   start1 <- max(noise[noise$id == paste0("id_", i) & noise$group == "a", "time"])
+#   start2 <- max(noise[noise$id == paste0("id_", i) & noise$group == "b", "time"])
+#   noise2_i <- rbind(
+#     data.frame(
+#       id = paste0("id_", i), time = start1:40, group = "a",
+#       y = c(runif(length(start1:40), 15, 50))
+#     ),
+#     data.frame(
+#       id = paste0("id_", i), time = start2:40, group = "b",
+#       y = c(runif(length(start2:40), 15, 50))
+#     )
+#   )
+#   return(noise2_i)
+# }))
+# simdf <- rbind(noise, noise2)
 
 ## ----echo=TRUE, eval=FALSE----------------------------------------------------
-#  ss <- growthSS(
-#    model = "int + int", form = y ~ time | id / group, sigma = "int + int",
-#    list(
-#      "int1" = 10, "changePoint1" = 10, "int2" = 20, # main model
-#      "sigmaint1" = 10, "sigmachangePoint1" = 10, "sigmaint2" = 10
-#    ), # sub model
-#    df = simdf, type = "brms"
-#  )
-#  
-#  fit <- fitGrowth(ss, backend = "cmdstanr", iter = 500, chains = 1, cores = 1)
+# ss <- growthSS(
+#   model = "int + int", form = y ~ time | id / group, sigma = "int + int",
+#   list(
+#     "int1" = 10, "changePoint1" = 10, "int2" = 20, # main model
+#     "sigmaint1" = 10, "sigmachangePoint1" = 10, "sigmaint2" = 10
+#   ), # sub model
+#   df = simdf, type = "brms"
+# )
+# 
+# fit <- fitGrowth(ss, backend = "cmdstanr", iter = 500, chains = 1, cores = 1)
 
 ## ----echo=FALSE, eval=FALSE---------------------------------------------------
-#  set.seed(123)
-#  noise <- do.call(rbind, lapply(1:30, function(i) {
-#    chngpt <- rnorm(2, 18, 2)
-#    rbind(
-#      data.frame(
-#        id = paste0("id_", i), time = 1:chngpt[1], group = "a",
-#        y = c(runif(chngpt[1] - 1, 0, 20), rnorm(1, 5, 1))
-#      ),
-#      data.frame(
-#        id = paste0("id_", i), time = 1:chngpt[2], group = "b",
-#        y = c(runif(chngpt[2] - 1, 0, 20), rnorm(1, 5, 1))
-#      )
-#    )
-#  }))
-#  signal <- growthSim("linear",
-#    n = 30, t = 20,
-#    params = list("A" = c(3, 5))
-#  )
-#  signal <- do.call(rbind, lapply(unique(paste0(signal$id, signal$group)), function(int) {
-#    noisesub <- noise[paste0(noise$id, noise$group) == int, ]
-#    signalSub <- signal[paste0(signal$id, signal$group) == int, ]
-#    y_end <- noisesub[noisesub$time == max(noisesub$time), "y"]
-#    signalSub$time <- signalSub$time + max(noisesub$time)
-#    signalSub$y <- y_end + signalSub$y
-#    signalSub
-#  }))
-#  simdf <- rbind(noise, signal)
+# set.seed(123)
+# noise <- do.call(rbind, lapply(1:30, function(i) {
+#   chngpt <- rnorm(2, 18, 2)
+#   noise_i <- rbind(
+#     data.frame(
+#       id = paste0("id_", i), time = 1:chngpt[1], group = "a",
+#       y = c(runif(chngpt[1] - 1, 0, 20), rnorm(1, 5, 1))
+#     ),
+#     data.frame(
+#       id = paste0("id_", i), time = 1:chngpt[2], group = "b",
+#       y = c(runif(chngpt[2] - 1, 0, 20), rnorm(1, 5, 1))
+#     )
+#   )
+#   return(noise_i)
+# }))
+# signal <- growthSim("linear",
+#   n = 30, t = 20,
+#   params = list("A" = c(3, 5))
+# )
+# signal <- do.call(rbind, lapply(unique(paste0(signal$id, signal$group)), function(int) {
+#   noisesub <- noise[paste0(noise$id, noise$group) == int, ]
+#   signalSub <- signal[paste0(signal$id, signal$group) == int, ]
+#   y_end <- noisesub[noisesub$time == max(noisesub$time), "y"]
+#   signalSub$time <- signalSub$time + max(noisesub$time)
+#   signalSub$y <- y_end + signalSub$y
+#   return(signalSub)
+# }))
+# simdf <- rbind(noise, signal)
 
 ## ----echo=TRUE, eval=FALSE----------------------------------------------------
-#  ss <- growthSS(
-#    model = "int + linear", form = y ~ time | id / group, sigma = "int + linear",
-#    list(
-#      "int1" = 10, "changePoint1" = 10, "linear2A" = 20,
-#      "sigmaint1" = 10, "sigmachangePoint1" = 10, "sigmalinear2A" = 10
-#    ),
-#    df = simdf, type = "brms"
-#  )
-#  fit <- fitGrowth(ss, backend = "cmdstanr", iter = 500, chains = 1, cores = 1)
+# ss <- growthSS(
+#   model = "int + linear", form = y ~ time | id / group, sigma = "int + linear",
+#   list(
+#     "int1" = 10, "changePoint1" = 10, "linear2A" = 20,
+#     "sigmaint1" = 10, "sigmachangePoint1" = 10, "sigmalinear2A" = 10
+#   ),
+#   df = simdf, type = "brms"
+# )
+# fit <- fitGrowth(ss, backend = "cmdstanr", iter = 500, chains = 1, cores = 1)
 
 ## ----eval=FALSE, echo=FALSE---------------------------------------------------
-#  set.seed(123)
-#  noise <- do.call(rbind, lapply(1:30, function(i) {
-#    chngpt <- rnorm(2, 18, 2)
-#    rbind(
-#      data.frame(
-#        id = paste0("id_", i), time = 1:chngpt[1], group = "a",
-#        y = c(runif(chngpt[1] - 1, 0, 20), rnorm(1, 5, 1))
-#      ),
-#      data.frame(
-#        id = paste0("id_", i), time = 1:chngpt[2], group = "b",
-#        y = c(runif(chngpt[2] - 1, 0, 20), rnorm(1, 5, 1))
-#      )
-#    )
-#  }))
-#  signal <- growthSim("logistic",
-#    n = 20, t = 30,
-#    params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5))
-#  )
-#  signal <- do.call(rbind, lapply(unique(paste0(signal$id, signal$group)), function(int) {
-#    noisesub <- noise[paste0(noise$id, noise$group) == int, ]
-#    signalSub <- signal[paste0(signal$id, signal$group) == int, ]
-#    y_end <- noisesub[noisesub$time == max(noisesub$time), "y"]
-#    signalSub$time <- signalSub$time + max(noisesub$time)
-#    signalSub$y <- y_end + signalSub$y
-#    signalSub
-#  }))
-#  simdf <- rbind(noise, signal)
-#  simdf <- simdf[simdf$time < 45, ]
+# set.seed(123)
+# noise <- do.call(rbind, lapply(1:30, function(i) {
+#   chngpt <- rnorm(2, 18, 2)
+#   noise_i <- rbind(
+#     data.frame(
+#       id = paste0("id_", i), time = 1:chngpt[1], group = "a",
+#       y = c(runif(chngpt[1] - 1, 0, 20), rnorm(1, 5, 1))
+#     ),
+#     data.frame(
+#       id = paste0("id_", i), time = 1:chngpt[2], group = "b",
+#       y = c(runif(chngpt[2] - 1, 0, 20), rnorm(1, 5, 1))
+#     )
+#   )
+#   return(noise_i)
+# }))
+# signal <- growthSim("logistic",
+#   n = 20, t = 30,
+#   params = list("A" = c(200, 160), "B" = c(13, 11), "C" = c(3, 3.5))
+# )
+# signal <- do.call(rbind, lapply(unique(paste0(signal$id, signal$group)), function(int) {
+#   noisesub <- noise[paste0(noise$id, noise$group) == int, ]
+#   signalSub <- signal[paste0(signal$id, signal$group) == int, ]
+#   y_end <- noisesub[noisesub$time == max(noisesub$time), "y"]
+#   signalSub$time <- signalSub$time + max(noisesub$time)
+#   signalSub$y <- y_end + signalSub$y
+#   return(signalSub)
+# }))
+# simdf <- rbind(noise, signal)
+# simdf <- simdf[simdf$time < 45, ]
 
 ## ----echo=TRUE, eval=FALSE----------------------------------------------------
-#  ss <- growthSS(
-#    model = "int+logistic", form = y ~ time | id / group, sigma = "int + spline",
-#    list(
-#      "int1" = 5, "changePoint1" = 10,
-#      "logistic2A" = 130, "logistic2B" = 10, "logistic2C" = 3,
-#      "sigmaint1" = 5, "sigmachangePoint1" = 15
-#    ),
-#    df = simdf, type = "brms"
-#  )
-#  fit <- fitGrowth(ss, backend = "cmdstanr", iter = 500, chains = 1, cores = 1)
+# ss <- growthSS(
+#   model = "int+logistic", form = y ~ time | id / group, sigma = "int + spline",
+#   list(
+#     "int1" = 5, "changePoint1" = 10,
+#     "logistic2A" = 130, "logistic2B" = 10, "logistic2C" = 3,
+#     "sigmaint1" = 5, "sigmachangePoint1" = 15
+#   ),
+#   df = simdf, type = "brms"
+# )
+# fit <- fitGrowth(ss, backend = "cmdstanr", iter = 500, chains = 1, cores = 1)
 
 ## ----eval=FALSE---------------------------------------------------------------
-#  print(load(url("https://raw.githubusercontent.com/joshqsumner/pcvrTestData/main/brmsFits.rdata")))
-#  from3to25 <- list(
-#    fit_3, fit_5, fit_7, fit_9, fit_11, fit_13,
-#    fit_15, fit_17, fit_19, fit_21, fit_23, fit_25
-#  )
-#  
-#  distributionPlot(fits = from3to25, form = y ~ time | id / group, params = c("A", "B", "C"), d = simdf)
+# print(load(url("https://raw.githubusercontent.com/joshqsumner/pcvrTestData/main/brmsFits.rdata")))
+# from3to25 <- list(
+#   fit_3, fit_5, fit_7, fit_9, fit_11, fit_13,
+#   fit_15, fit_17, fit_19, fit_21, fit_23, fit_25
+# )
+# 
+# distributionPlot(fits = from3to25, form = y ~ time | id / group, params = c("A", "B", "C"), d = simdf)
 
