@@ -34,6 +34,8 @@ test_that("Logistic brms model pipeline", {
   expect_s3_class(plot2, "ggplot")
   plot2.5 <- brmViolin(fit, ss, "B_groupb/B_groupa > 1.05")
   expect_s3_class(plot2.5, "ggplot")
+  plot2.75 <- brmViolin(fit, ss, "abs(1 - ((...)/(C_groupb - B_groupa))) > 0.05")
+  expect_s3_class(plot2.75, "ggplot")
   ss2 <- growthSS(
     model = "gompertz", form = y ~ time | id / group, sigma = "logistic",
     list("A" = 130, "B" = 10, "C" = 1, "sigmaA" = 20, "sigmaB" = 10, "sigmaC" = 2),
@@ -194,11 +196,12 @@ test_that("Hierarchical Model Works", {
     df = simdf, type = "brms",
     hierarchy = list("A" = "int_linear")
   )
-  lapply(ss, head)
   fit <- fitGrowth(ss, iter = 600, cores = 1, chains = 1, backend = "cmdstanr")
   expect_s3_class(fit, "brmsfit")
   p <- growthPlot(fit, ss$pcvrForm, df = ss$df)
   expect_s3_class(p, "ggplot")
+  p <- growthPlot(fit, ss$pcvrForm, df = ss$df, hierarchy_value = seq(8, 12, 1))
+  expect_s3_class(p, "ggplot")
 })
 
 test_that("Changepoint model can be specified", {
@@ -207,7 +210,7 @@ test_that("Changepoint model can be specified", {
   set.seed(123)
   noise <- do.call(rbind, lapply(1:30, function(i) {
     chngpt <- c(20, 21)
-    rbind(
+    noise_i <- rbind(
       data.frame(
         id = paste0("id_", i), time = 1:chngpt[1], group = "a",
         y = c(runif(chngpt[1] - 1, 0, 20), rnorm(1, 5, 1))
@@ -217,11 +220,12 @@ test_that("Changepoint model can be specified", {
         y = c(runif(chngpt[2] - 1, 0, 20), rnorm(1, 5, 1))
       )
     )
+    return(noise_i)
   }))
   noise2 <- do.call(rbind, lapply(1:30, function(i) {
     start1 <- max(noise[noise$id == paste0("id_", i) & noise$group == "a", "time"])
     start2 <- max(noise[noise$id == paste0("id_", i) & noise$group == "b", "time"])
-    rbind(
+    noise2_i <- rbind(
       data.frame(
         id = paste0("id_", i), time = start1:40, group = "a",
         y = c(runif(length(start1:40), 15, 50))
@@ -231,6 +235,7 @@ test_that("Changepoint model can be specified", {
         y = c(runif(length(start2:40), 15, 50))
       )
     )
+    return(noise2_i)
   }))
   simdf <- rbind(noise, noise2)
   ss <- growthSS(
@@ -809,7 +814,7 @@ if (file.exists("/home/josh/Desktop/")) {
 
     noise <- do.call(rbind, lapply(1:30, function(i) {
       chngpt <- rnorm(2, 18, 2)
-      rbind(
+      noise_i <- rbind(
         data.frame(
           id = paste0("id_", i), time = 1:chngpt[1], group = "a",
           y = c(runif(chngpt[1] - 1, 0, 20), rnorm(1, 5, 1))
@@ -819,12 +824,13 @@ if (file.exists("/home/josh/Desktop/")) {
           y = c(runif(chngpt[2] - 1, 0, 20), rnorm(1, 5, 1))
         )
       )
+      return(noise_i)
     }))
     noise2 <- do.call(rbind, lapply(1:30, function(i) {
       start1 <- max(noise[noise$id == paste0("id_", i) & noise$group == "a", "time"])
       start2 <- max(noise[noise$id == paste0("id_", i) & noise$group == "b", "time"])
 
-      rbind(
+      noise2_i <- rbind(
         data.frame(
           id = paste0("id_", i), time = start1:40, group = "a",
           y = c(runif(length(start1:40), 15, 50))
@@ -834,6 +840,7 @@ if (file.exists("/home/josh/Desktop/")) {
           y = c(runif(length(start2:40), 15, 50))
         )
       )
+      return(noise2_i)
     }))
     simdf <- rbind(noise, noise2)
 
@@ -860,7 +867,7 @@ if (file.exists("/home/josh/Desktop/")) {
 
     noise <- do.call(rbind, lapply(1:30, function(i) {
       chngpt <- c(20, 21)
-      rbind(
+      noise_i <- rbind(
         data.frame(
           id = paste0("id_", i), time = 1:chngpt[1], group = "a",
           y = c(runif(chngpt[1] - 1, 0, 20), rnorm(1, 5, 1))
@@ -870,12 +877,13 @@ if (file.exists("/home/josh/Desktop/")) {
           y = c(runif(chngpt[2] - 1, 0, 20), rnorm(1, 5, 1))
         )
       )
+      return(noise_i)
     }))
     noise2 <- do.call(rbind, lapply(1:30, function(i) {
       start1 <- max(noise[noise$id == paste0("id_", i) & noise$group == "a", "time"])
       start2 <- max(noise[noise$id == paste0("id_", i) & noise$group == "b", "time"])
 
-      rbind(
+      noise2_i <- rbind(
         data.frame(
           id = paste0("id_", i), time = start1:40, group = "a",
           y = c(runif(length(start1:40), 15, 50))
@@ -885,6 +893,7 @@ if (file.exists("/home/josh/Desktop/")) {
           y = c(runif(length(start2:40), 15, 50))
         )
       )
+      return(noise2_i)
     }))
     simdf <- rbind(noise, noise2)
 
@@ -914,7 +923,7 @@ if (file.exists("/home/josh/Desktop/")) {
 
     noise <- do.call(rbind, lapply(1:30, function(i) {
       chngpt <- rnorm(2, 18, 2)
-      rbind(
+      noise_i <- rbind(
         data.frame(
           id = paste0("id_", i), time = 1:chngpt[1], group = "a",
           y = c(runif(chngpt[1] - 1, 0, 20), rnorm(1, 5, 1))
@@ -924,12 +933,13 @@ if (file.exists("/home/josh/Desktop/")) {
           y = c(runif(chngpt[2] - 1, 0, 20), rnorm(1, 5, 1))
         )
       )
+      return(noise_i)
     }))
     noise2 <- do.call(rbind, lapply(1:30, function(i) {
       start1 <- max(noise[noise$id == paste0("id_", i) & noise$group == "a", "time"])
       start2 <- max(noise[noise$id == paste0("id_", i) & noise$group == "b", "time"])
 
-      rbind(
+      noise2_i <- rbind(
         data.frame(
           id = paste0("id_", i), time = start1:40, group = "a",
           y = c(runif(length(start1:40), 15, 50))
@@ -939,6 +949,7 @@ if (file.exists("/home/josh/Desktop/")) {
           y = c(runif(length(start2:40), 15, 50))
         )
       )
+      return(noise2_i)
     }))
     simdf <- rbind(noise, noise2)
 
@@ -974,7 +985,7 @@ if (file.exists("/home/josh/Desktop/")) {
     set.seed(123)
     noise <- do.call(rbind, lapply(1:30, function(i) {
       chngpt <- rnorm(2, 18, 2)
-      rbind(
+      noise_i <- rbind(
         data.frame(
           id = paste0("id_", i), time = 1:chngpt[1], group = "a",
           y = c(runif(chngpt[1] - 1, 0, 20), rnorm(1, 5, 1))
@@ -984,6 +995,7 @@ if (file.exists("/home/josh/Desktop/")) {
           y = c(runif(chngpt[2] - 1, 0, 20), rnorm(1, 5, 1))
         )
       )
+      return(noise_i)
     }))
     signal <- growthSim("linear",
       n = 30, t = 20,
@@ -995,7 +1007,7 @@ if (file.exists("/home/josh/Desktop/")) {
       y_end <- noisesub[noisesub$time == max(noisesub$time), "y"]
       signalSub$time <- signalSub$time + max(noisesub$time)
       signalSub$y <- y_end + signalSub$y
-      signalSub
+      return(signalSub)
     }))
     simdf <- rbind(noise, signal)
     ss <- growthSS(
@@ -1028,7 +1040,7 @@ if (file.exists("/home/josh/Desktop/")) {
     set.seed(123)
     noise <- do.call(rbind, lapply(1:30, function(i) {
       chngpt <- rnorm(2, 18, 2)
-      rbind(
+      noise_i <- rbind(
         data.frame(
           id = paste0("id_", i), time = 1:chngpt[1], group = "a",
           y = c(runif(chngpt[1] - 1, 0, 20), rnorm(1, 5, 1))
@@ -1038,6 +1050,7 @@ if (file.exists("/home/josh/Desktop/")) {
           y = c(runif(chngpt[2] - 1, 0, 20), rnorm(1, 5, 1))
         )
       )
+      return(noise_i)
     }))
     signal <- growthSim("logistic",
       n = 20, t = 30,
@@ -1049,7 +1062,7 @@ if (file.exists("/home/josh/Desktop/")) {
       y_end <- noisesub[noisesub$time == max(noisesub$time), "y"]
       signalSub$time <- signalSub$time + max(noisesub$time)
       signalSub$y <- y_end + signalSub$y
-      signalSub
+      return(signalSub)
     }))
     simdf <- rbind(noise, signal)
     simdf <- simdf[simdf$time < 45, ]
@@ -1099,7 +1112,7 @@ if (file.exists("/home/josh/Desktop/")) {
       y_end_p1 <- p1[p1$time == max(p1$time), "y"]
       p2$time <- p2$time + max(p1$time)
       p2$y <- y_end_p1 + p2$y
-      p2
+      return(p2)
     }))
     simdf <- rbind(simdf1, simdf2_adj)
 
